<div align="center">
    </a>
    <br />
    <img align="center" src="https://cdn.discordapp.com/attachments/1092315227057561630/1230745160464338954/flare.png?ex=66346fc0&is=6621fac0&hm=b6dafeba296665988c5afaad3b1dd3d82abf143f1fdc76cd7299e259c94564cd&">
    
   ![GitHub last commit](https://img.shields.io/github/last-commit/t-a-g-o/flare-helper)
   ![GitHub issues](https://img.shields.io/github/issues-raw/t-a-g-o/flare-helper)
   ![GitHub](https://img.shields.io/github/license/t-a-g-o/flare-helper)
    
</div>

> This python modules cleans up the requests codes needed in order to validate accounts